<?php

	# 		Air Quality Index US
	# 		Namespace:		airQualityUS
	#		Meteotemplate Block
	
	#		v2.0	Nov 11, 2016
	#			- added logging
	#			- CSS tweaks
	
	$thisBlockVersion = "2.0";
	
	$time = microtime();
	$time = explode(' ', $time);
	$time = $time[1] + $time[0];
	$blockStartTime = $time;
	
	if(file_exists("settings.php")){
		include("settings.php");
	}
	else{
		echo "Please go to your admin section and go through the settings for this block first.";
		die();
	}
	
	$errorLog[] = array("","%c Loading Air Quality Index U.S. Block ".$thisBlockVersion."','font-weight:bold;color:green");
	
	$errorLog[] = array("","Region code set: ".$regionCode);
	$errorLog[] = array("","Cache time set (minutes): ".$cacheTime);
	
	// load theme
	$designTheme = json_decode(file_get_contents("../../css/theme.txt"),true);
	$theme = $designTheme['theme'];
	
	include("../../../config.php");
	include("../../../css/design.php");
	include("../../../scripts/functions.php");
	
	$languageRaw = file_get_contents($baseURL."lang/gb.php");
	$language['gb'] = json_decode($languageRaw,true);
	$languageRaw = file_get_contents($baseURL."lang/".$lang.".php");
	$language[$lang] = json_decode($languageRaw,true);
	
	if(file_exists("cache/airQualityCache.txt")){
		if (time()-filemtime("cache/airQualityCache.txt") > 60 * $cacheTime) {
			unlink("cache/airQualityCache.txt");
			$errorLog[] = array("","Cache outdated, deleting cache file.");
			if(file_exists("cache/airQualityCache.txt")){
				$errorLog[] = array("w","Cache file was not deleted, likely permission problem. Cache file cannot be refreshed and data is outdated.");
			}
		}
	}

	if(file_exists("cache/airQualityCache.txt")){
		$fileData = file_get_contents("cache/airQualityCache.txt");
		$errorLog[] = array("","Loading data from cache file.");
	}
	else { 
		$url = "http://feeds.enviroflash.info/rss/realtime/".$regionCode.".xml";
		$fileData = curlMain($url,8);
		$errorLog[] = array("","Loading data from ".$url);
		if($fileData==""){
			$errorLog[] = array("w","No data returned from the URL specified.");
			$errorLog[] = array("","Trying alternative method for retrieving data...");
			$fileData = file_get_contents($url);
			if($fileData==""){
				$errorLog[] = array("e","No data loaded even using alternative method.");
			}
			else{
				$errorLog[] = array("","Data loaded using alternative method.");
			}
		}
		if($fileData!=""){
			$errorLog[] = array("","Saving cache file for Air Quality U.S.");
			$cached = fopen("cache/airQualityCache.txt", "w");
			fwrite($cached, $fileData);
			fclose($cached);
			if(!file_exists("cache/airQualityCache.txt")){
				$errorLog[] = array("w","Cache file was not created - likely permission issue. Cache directory not writable.");
			}
		}
	}
	
	$quality = array();
	
	$conditions = array('Good','Moderate','Unhealthy for Sensitive Groups','Unhealthy','Very Unhealthy','Hazardous');
	$bgColors = array('#00B300','#FFFF00','#FF8000','#FF2626','#B30086','#000000');
	$fontColors = array('#FFFFFF','#000000','#FFFFFF','#FFFFFF','#FFFFFF','#FFFFFF');
	
	if($fileData!=""){
		$errorLog[] = array("","Parsing data for Air Quality U.S. Block.");
		$dataRaw = simplexml_load_string($fileData);
		
		$location = $dataRaw->channel->item[0]->title;
		$location = str_replace("- Current Air Quality","",$location);
		$dataString = $dataRaw->channel->item[0]->description;
		$dataString = preg_replace("/\n/", "", $dataString);
		$dataString = preg_replace('/\s+/', ' ', $dataString);
		
		preg_match("/Last Update:(.*?)</",$dataString,$matches);
		if(count($matches)==2){
			$quality['update'] = trim($matches[1]);
		}
					
		preg_match("/([0-9]*?) AQI - Particle Pollution \(2.5 microns\)/",$dataString,$matches);
		if(count($matches)==2){
			$quality['PP2.5'] = (int)trim($matches[1]);
		}
		preg_match("/([0-9]*?) AQI - Particle Pollution \(10 microns\)/",$dataString,$matches);
		if(count($matches)==2){
			$quality['PP10'] = (int)trim($matches[1]);
		}
		preg_match("/([0-9]*?) AQI - Ozone/",$dataString,$matches);
		if(count($matches)==2){
			$quality['ozone'] = (int)trim($matches[1]);
		}
		
		$details = "<table class='table aqiUSTable'>";
		
		if(array_key_exists('PP2.5',$quality)){
			$position = getCondition($quality['PP2.5']);
			$details = $details."<tr><td style='padding-right:2px;font-weight:bold'>PM2.5</td><td style='text-align:justify'>";
			if($position==0){
				$details = $details."It’s a great day to be active outside.";
			}
			if($position==1){
				$details = $details."<strong>Unusually sensitive people</strong><br>Consider reducing prolonged or heavy exertion. Watch for symptoms such as coughing or shortness of breath. These are signs to take it easier.<br><br><strong>Everyone else</strong><br>It’s a good day to be active outside.";
			}
			if($position==2){
				$details = $details."<strong>Sensitive groups</strong><br>Reduce prolonged or heavy exertion. It’s OK to be active outside, but take more breaks and do less intense activities. Watch for symptoms such as coughing or shortness of breath.<br><br><strong>People with asthma</strong><br>People with asthma should follow their asthma action plans and keep quick relief medicine handy.<br><br><strong>People with heart disease<br>Symptoms such as palpitations, shortness of breath, or unusual fatigue may indicate a serious problem. If you have any of these, contact your heath care provider.";
			}
			if($position==3){
				$details = $details."<strong>Sensitive groups</strong><br>Avoid prolonged or heavy exertion. Move activities indoors or reschedule to a time when the air quality is better.<br><br><strong>Everyone else</strong><br>Reduce prolonged or heavy exertion. Take more breaks during all outdoor activities.";
			}
			if($position==4){
				$details = $details."<strong>Sensitive groups</strong><br>Avoid all physical activity outdoors. Move activities indoors or reschedule to a time when air quality is better.<br><br><strong>Everyone else</strong><br>Avoid prolonged or heavy exertion. Consider moving activities indoors or rescheduling to a time when air quality is better.";
			}
			if($position==5){
				$details = $details."<strong>Everyone</strong><br>Avoid all physical activity outdoors.<br><br><strong>Sensitive groups</strong><br>Remain indoors and keep activity levels low. Follow tips for keeping particle levels low indoors.";
			}
			$details = $details."</td></tr>";
		}
		
		if(array_key_exists('PP10',$quality)){
			$position = getCondition($quality['PP10']);
			$details = $details."<tr><td style='padding-right:2px;font-weight:bold'>PM10</td><td style='text-align:justify'>";
			if($position==0){
				$details = $details."It’s a great day to be active outside.";
			}
			if($position==1){
				$details = $details."<strong>Unusually sensitive people</strong><br>Consider reducing prolonged or heavy exertion. Watch for symptoms such as coughing or shortness of breath. These are signs to take it easier.<br><br><strong>Everyone else</strong><br>It’s a good day to be active outside.";
			}
			if($position==2){
				$details = $details."<strong>Sensitive groups</strong><br>Reduce prolonged or heavy exertion. It’s OK to be active outside, but take more breaks and do less intense activities. Watch for symptoms such as coughing or shortness of breath.<br><br><strong>People with asthma</strong><br>People with asthma should follow their asthma action plans and keep quick relief medicine handy.<br><br><strong>People with heart disease<br>Symptoms such as palpitations, shortness of breath, or unusual fatigue may indicate a serious problem. If you have any of these, contact your heath care provider.";
			}
			if($position==3){
				$details = $details."<strong>Sensitive groups</strong><br>Avoid prolonged or heavy exertion. Move activities indoors or reschedule to a time when the air quality is better.<br><br><strong>Everyone else</strong><br>Reduce prolonged or heavy exertion. Take more breaks during all outdoor activities.";
			}
			if($position==4){
				$details = $details."<strong>Sensitive groups</strong><br>Avoid all physical activity outdoors. Move activities indoors or reschedule to a time when air quality is better.<br><br><strong>Everyone else</strong><br>Avoid prolonged or heavy exertion. Consider moving activities indoors or rescheduling to a time when air quality is better.";
			}
			if($position==5){
				$details = $details."<strong>Everyone</strong><br>Avoid all physical activity outdoors.<br><br><strong>Sensitive groups</strong><br>Remain indoors and keep activity levels low. Follow tips for keeping particle levels low indoors.";
			}
			$details = $details."</td></tr>";
		}
		
		if(array_key_exists('ozone',$quality)){
			$position = getCondition($quality['ozone']);
			$details = $details."<tr><td style='padding-right:2px;font-weight:bold'>Ozone</td><td style='text-align:justify'>";
			if($position==0){
				$details = $details."It’s a great day to be active outside.";
			}
			if($position==1){
				$details = $details."<strong>Unusually sensitive people</strong><br>Consider reducing prolonged or heavy outdoor exertion. Watch for symptoms such as coughing or shortness of breath. These are signs to take it a little easier.<br><br><strong>Everyone else</strong><br>It’s a good day to be active outside.";
			}
			if($position==2){
				$details = $details."<strong>Sensitive groups</strong><br>Reduce prolonged or heavy outdoor exertion. Take more breaks, do less intense activities. Watch for symptoms such as coughing or shortness of breath. Schedule outdoor activities in the morning when ozone is lower.<br><br><strong>People with asthma</strong><br>People with asthma should follow their asthma action plans and keep quick relief medicine handy.";
			}
			if($position==3){
				$details = $details."<strong>Sensitive groups</strong><br>Avoid prolonged or heavy outdoor exertion. Schedule outdoor activities in the morning when ozone is lower. Consider moving activities indoors.<br><br><strong>People with asthma</strong><br>People with asthma should keep quick-relief medicine handy.<br><br><strong>Everyone else</strong><br>Reduce prolonged or heavy outdoor exertion. Take more breaks, do less intense activities. Schedule outdoor activities in the morning when ozone is lower.";
			}
			if($position==4){
				$details = $details."<strong>Sensitive groups</strong><br>Avoid all physical activity outdoors. Move activities indoors or reschedule to a time when air quality is better.<br><br><strong>People with asthma</strong><br>People with asthma should keep quick-relief medicine handy.<br><br><strong>Everyone else</strong><br>Avoid prolonged or heavy outdoor exertion. Schedule outdoor activities in the morning when ozone is lower. Consider moving activities indoors.";
			}
			if($position==5){
				$details = $details."<strong>Everyone</strong><br>Avoid all physical activity outdoors.";
			}
			$details = $details."</td></tr>";
		}
		
		$details = $details."</table>";
		
	}
	
	function getCondition($index){
		if($index<=50){
			$position = 0;
		}
		else if($index>=51 && $index<=100){
			$position = 1;
		}
		else if($index>=101 && $index<=150){
			$position = 2;
		}
		else if($index>=151 && $index<=200){
			$position = 3;
		}
		else if($index>=201 && $index<=300){
			$position = 4;
		}
		else{
			$position = 5;
		}
		return $position;
	}
	
?>
	<style>
		.aqiUSicon{
			max-width:65px;
			width:100%;
		}
		.aqiUSTable td{
			padding: 2%;
		}
	</style>
	<?php 
		if(count($quality)>0){
	?>
		<div style="width:98%;margin:0 auto;text-align:center">
			<span style="font-size:1.6em;font-variant:small-caps;font-weight:bold">Air Quality Index</span>
			<br>
			<span style="font-size:1.2em;font-variant:small-caps;font-weight:bold"><?php echo $location?></span><br>
			<?php
				if(array_key_exists('PP2.5',$quality) || array_key_exists('PP10',$quality) || array_key_exists('ozone',$quality)){
			?>	
					<?php
						if(array_key_exists('update',$quality)){
					?>
							<span style="color:#<?php echo $color_schemes[$design2]['400']?>;font-size:1.0em;font-variant:small-caps;font-weight:bold"><?php echo $quality['update']?></span><br>
					<?php
						}
					?>
					<?php
						if(array_key_exists('PP2.5',$quality)){
							$position = getCondition($quality['PP2.5']);
					?>
							<div style="margin:0 auto;padding:10px;display:inline-block;width:20%;text-align:center">
								<img src="homepage/blocks/airQualityUS/icons/<?php echo $theme?>/pm25.png" class="aqiUSicon"><br>
								<div style="display:inline-block;min-width:45px;font-weight:bold;font-size:1.6em;border:3px solid white;border-radius:5px;padding:2px;background:<?php echo $bgColors[$position]?>;color:<?php echo $fontColors[$position]?>"><?php echo $quality['PP2.5']?></div><br><br><span style="font-size:1.3em;font-variant:small-caps;font-weight:bold"><?php echo $conditions[$position]?></span>
							</div>
					<?php
						}
					?>
					<?php
						if(array_key_exists('PP10',$quality)){
							$position = getCondition($quality['PP10']);
					?>
							<div style="margin:0 auto;padding:10px;display:inline-block;width:20%;text-align:center">
								<img src="homepage/blocks/airQualityUS/icons/<?php echo $theme?>/pm10.png" class="aqiUSicon"><br>
								<div style="display:inline-block;min-width:45px;font-weight:bold;font-size:1.6em;border:3px solid white;border-radius:5px;padding:2px;background:<?php echo $bgColors[$position]?>;color:<?php echo $fontColors[$position]?>"><?php echo $quality['PP10']?></div><br><br><span style="font-size:1.3em;font-variant:small-caps;font-weight:bold"><?php echo $conditions[$position]?></span>
							</div>
					<?php
						}
					?>
					<?php
						if(array_key_exists('ozone',$quality)){
							$position = getCondition($quality['ozone']);
					?>
							<div style="margin:0 auto;padding:10px;display:inline-block;width:20%;text-align:center">
								<img src="homepage/blocks/airQualityUS/icons/<?php echo $theme?>/o3.png" class="aqiUSicon"><br>
								<div style="display:inline-block;min-width:45px;font-weight:bold;font-size:1.6em;border:3px solid white;border-radius:5px;padding:2px;background:<?php echo $bgColors[$position]?>;color:<?php echo $fontColors[$position]?>"><?php echo $quality['ozone']?></div><br><br><span style="font-size:1.3em;font-variant:small-caps;font-weight:bold"><?php echo $conditions[$position]?></span>
							</div>
					<?php
						}
					?>
					<br>
					<div id="aqiUSDetails" class="details">
						<?php echo $details?>
					</div>
					<span class="more" onclick="txt = $('#aqiUSDetails').is(':visible') ? '<?php echo lang('more','l')?>' : '<?php echo lang('hide','l')?>';$('#aqiUSDetails').slideToggle(800);$(this).text(txt)">
						<?php echo lang('more','l')?>
					</span>
					<br>
					<a href="#"><span id="AIQinfoDivOpener">AQI Info</span></a>
			<?php
				}
				else{
			?>
					<br><span style="font-size:1.0em;font-variant:small-caps;font-weight:bold">Current Air Quality unavailable</span>
			<?php
				}
			?>
			<div style="font-size:0.8em;font-variant:small-caps"><?php echo lang('data source','c')?>: airnow.gov</div>
		</div>
	<?php
		}
		else{
			echo "<br>Data N/A";
		}
	?>
	<div id="AIQinfoDiv">
		<h1>Air Quality Index</h1>
		<br>
		<table class="table">
			<tr>
				<td>
					<div style="text-align:center;display:inline-block;min-width:45px;font-weight:bold;font-size:1.0em;border:3px solid white;border-radius:5px;padding:2px;margin:10px;background:<?php echo $bgColors[0]?>;color:<?php echo $fontColors[0]?>">Good</div>
				</td>
				<td style="text-align:justify;padding:3px">
					Air quality is considered satisfactory, and air pollution poses little or no risk.
				</td>
			</tr>
			<tr>
				<td>
					<div style="text-align:center;display:inline-block;min-width:45px;font-weight:bold;font-size:1.0em;border:3px solid white;border-radius:5px;padding:2px;margin:10px;background:<?php echo $bgColors[1]?>;color:<?php echo $fontColors[1]?>">Moderate</div>
				</td>
				<td style="text-align:justify;padding:3px">
					Air quality is acceptable; however, for some pollutants there may be a moderate health concern for a very small number of people. For example, people who are unusually sensitive to ozone may experience respiratory symptoms.
				</td>
			</tr>
			<tr>
				<td>
					<div style="text-align:center;display:inline-block;min-width:45px;font-weight:bold;font-size:1.0em;border:3px solid white;border-radius:5px;padding:2px;margin:10px;background:<?php echo $bgColors[2]?>;color:<?php echo $fontColors[2]?>">Unhealthy for Sensitive Groups</div>
				</td>
				<td style="text-align:justify;padding:3px">
					Although general public is not likely to be affected at this AQI range, people with lung disease, older adults and children are at a greater risk from exposure to ozone, whereas persons with heart and lung disease, older adults and children are at greater risk from the presence of particles in the air.
				</td>
			</tr>
			<tr>
				<td>
					<div style="text-align:center;display:inline-block;min-width:45px;font-weight:bold;font-size:1.0em;border:3px solid white;border-radius:5px;padding:2px;margin:10px;background:<?php echo $bgColors[3]?>;color:<?php echo $fontColors[3]?>">Unhealthy</div>
				</td>
				<td style="text-align:justify;padding:3px">
					Everyone may begin to experience some adverse health effects, and members of the sensitive groups may experience more serious effects.
				</td>
			</tr>
			<tr>
				<td>
					<div style="text-align:center;display:inline-block;min-width:45px;font-weight:bold;font-size:1.0em;border:3px solid white;border-radius:5px;padding:2px;margin:10px;background:<?php echo $bgColors[4]?>;color:<?php echo $fontColors[4]?>">Very Unhealthy</div>
				</td>
				<td style="text-align:justify;padding:3px">
					This would trigger a health alert signifying that everyone may experience more serious health effects.
				</td>
			</tr>	
			<tr>
				<td>
					<div style="text-align:center;display:inline-block;min-width:45px;font-weight:bold;font-size:1.0em;border:3px solid white;border-radius:5px;padding:2px;margin:10px;background:<?php echo $bgColors[5]?>;color:<?php echo $fontColors[5]?>">Hazardous</div>
				</td>
				<td style="text-align:justify;padding:3px">
					This would trigger a health warnings of emergency conditions. The entire population is more likely to be affected.
				</td>
			</tr>				
		</table>
		<br>
		<h2>PM<sub>2.5</sub></h2>
		<p>
			Fine particles (PM2.5) are 2.5 micrometers in diameter or smaller, and can only be seen with an electron microscope. Fine particles are produced from all types of combustion, including motor vehicles, power plants, residential wood burning, forest fires, agricultural burning, and some industrial processes.
		</p>
		<h2>PM<sub>10</sub></h2>
		<p>
			Coarse dust particles (PM10) are 2.5 to 10 micrometers in diameter. Sources include crushing or grinding operations and dust stirred up by vehicles on roads.
		</p>
		<h2>Ozone (tropospheric)</h2>
		<p>
			Ozone (O<sub>3</sub>) is a constituent of the troposphere. The troposphere extends from the Earth's surface to between 12 and 20 kilometers above sea level and consists of many layers. At abnormally high concentrations brought about by human activities (largely incomplete combustion of fossil fuels, such as gasoline, diesel, etc.), it is a pollutant, and a constituent of smog. Many highly energetic reactions produce it, ranging from combustion to photocopying. Often laser printers will have a smell of ozone[citation needed], which in high concentrations is toxic. Ozone is a powerful oxidizing agent readily reacting with other chemical compounds to make many possibly toxic oxides. Health effects depend on ozone precursors, which is a group of pollutants, primarily generated during the combustion of fossil fuels. Reaction with daylight ultraviolet (UV) rays and these precursors create ground-level ozone pollution.
		</p>
	</div>
	<script>
		$( "#AIQinfoDiv" ).dialog({
			autoOpen: false,
			show: {
				effect: "puff",
				duration: 500
			},
			hide: {
				effect: "puff",
				duration: 500
			},
			height: 800,
			width: '40%',
			position:{
				my: 'top', 
				at: 'top+5%'
			}
		});
		$("#AIQinfoDivOpener").click(function(){
			$( "#AIQinfoDiv" ).dialog( "open" );
		});
	</script>
	
	<?php
		$time = microtime();
		$time = explode(' ', $time);
		$time = $time[1] + $time[0];
		$blockEndTime = $time;
		$blockLoadTime = $blockEndTime - $blockStartTime;
		$blockLoadTime = round($blockLoadTime,4);
		$errorLog[] = array("","Block loaded in ".$blockLoadTime." s.");
		showLog($errorLog);
	?>
